couchdb.client

Package couchdb :: Module client |

# Module client

Python client API for CouchDB.

    >>> server = Server('http://localhost:5984/')
    >>> db = server.create('python-tests')
    >>> doc_id = db.create({'type': 'Person', 'name': 'John Doe'})
    >>> doc = db[doc_id]
    >>> doc['type']
    'Person'
    >>> doc['name']
    'John Doe'
    >>> del db[doc.id]
    >>> doc.id in db
    False

    >>> del server['python-tests']

Classes
| PreconditionFailed Exception raised when a 412 HTTP error is received in response to a request.
| ResourceNotFound Exception raised when a 404 HTTP error is received in response to a request.
| ResourceConflict Exception raised when a 409 HTTP error is received in response to a request.
| ServerError Exception raised when an unexpected HTTP error is received in response to a request.
| Server Representation of a CouchDB server.
| Database Representation of a database on a CouchDB server.
| Document Representation of a document in the database.
| ViewResults Representation of a parameterized view (either permanent or temporary) and the results it produces.
| Row Representation of a row as returned by database views.